@@ -1,6 +1,6 @@
 package Net::Kubernetes::Resource::Endpoint;
 # ABSTRACT: Object representatioon of a Kubernetes Endpoint
-$Net::Kubernetes::Resource::Endpoint::VERSION = '0.19';
+$Net::Kubernetes::Resource::Endpoint::VERSION = '0.20';
 use Moose;
 
 extends 'Net::Kubernetes::Resource';
@@ -10,6 +10,10 @@ has subsets => (
     isa   => 'ArrayRef[HashRef]',
 );
 
+augment as_hashref => sub {
+    my($self) = @_;
+    return ( subsets =>$self->subsets );
+};
 
 return 42;
 
@@ -25,7 +29,7 @@ Net::Kubernetes::Resource::Endpoint - Object representatioon of a Kubernetes End
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 AUTHOR
 
